==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/askrunlevel/askrunlevel.pm <==
/* _dict.cc 14/08/96 15.16.28 */
/* askrunlevel.cc 22/11/98 17.18.24 */
/* boot.cc 06/01/98 03.24.08 */
/* internal.cc 14/10/95 01.33.40 */
/* lilo.cc 06/04/99 22.52.30 */
PUBLIC LILO_PARM::LILO_PARM (void);
PUBLIC LILO_CONF::LILO_CONF (void);
PUBLIC LILO_CONF *LILO_CONFS::getitem (int no);
PUBLIC LILO_OTHER *LILO_OTHERS::getitem (int no);
PRIVATE void LILO::addunknown (LILO_CUR&cur, const char *line);
PRIVATE void LILO::parse_eq (const char *keyw,
	 const char *vals,
	 LILO_CUR&cur);
PRIVATE void LILO::parse_single (const char *pt, LILO_CUR&cur);
PRIVATE void LILO::compute_prefix (void);
PUBLIC LILO::LILO (void);
PUBLIC LILO_CONF *LILO::getconffromlabel (const char *lab);
PRIVATE void LILO::makecfgpath (const char *path, char *realpath);
PROTECTED void LILO::writeparm (FILE *fout,
	 LILO_PARM&p,
	 int global_parm);
PUBLIC int LILO::save (void);
PUBLIC void LILO_PARM::setupdia (DIALOG&dia);
PUBLIC int LILO::editdefaults (void);
PUBLIC bool LILO::is_duplicate (const SSTRING&label,
	 LILO_CONF *conf,
	 LILO_OTHER *other);
PUBLIC int LILO_CONF::edit (bool no_empty_root, LILO&lilo);
PUBLIC int LILO_OTHER::edit (LILO&lilo);
PUBLIC int LILO::editlinux (void);
PUBLIC int LILO::editothers (void);
PUBLIC int LILO::updateif (void);
PUBLIC LILO_CONF *LILO::getdefaultlinux (void);
PUBLIC void LILO::addkernel (const char *def_src,
	 const char *def_name);
PUBLIC void LILO::setdefault (void);
/* linuxrc.cc 09/05/97 23.34.38 */
/* modlist.cc 26/09/97 23.51.48 */
/* modules.cc 27/08/98 16.19.42 */
PUBLIC PARMVAL::PARMVAL (const char *_parm, const char *_line);
PUBLIC PARMVAL::PARMVAL (const char *_parm);
PUBLIC PARMVAL *PARMVALS::getitem (int no)const;
PUBLIC void PARMVALS::setoption (const char *optname, const char *val);
PUBLIC MODULE_LINE::MODULE_LINE (const SSTRING&pre_com,
	 const char *end_com);
PUBLIC MODULE_LINE::MODULE_LINE (void);
PUBLIC void MODULE_LINE::write (FILE *fout);
PUBLIC MODULE_LINE_IGNORE::MODULE_LINE_IGNORE (const char *_begin,
	 const SSTRING&pre_com,
	 const char *end_com);
PUBLIC void MODULE_LINE_IGNORE::write_begin (FILE *fout);
PUBLIC MODULE_LINE *MODULE_LINES::getitem (int no)const;
PUBLIC MODULE_CONF::MODULE_CONF (char *line,
	 const SSTRING&pre_com,
	 const char *end_com);
PUBLIC MODULE_CONF::MODULE_CONF (const char *_name);
PUBLIC void MODULE_CONF::write_begin (FILE *fout);
PUBLIC MODULE_CONF *MODULE_CONFS::getitem (int no)const;
PUBLIC MODULE_ALIAS::MODULE_ALIAS (const char *line,
	 const SSTRING&pre_com,
	 const char *end_com);
PUBLIC MODULE_ALIAS::MODULE_ALIAS (const char *_alias,
	 const char *_module);
PUBLIC void MODULE_ALIAS::write_begin (FILE *fout);
PUBLIC MODULE_ALIAS *MODULE_ALIASES::getitem (int no)const;
PUBLIC MODULES::MODULES (void);
PUBLIC int MODULES::write (void);
PUBLIC MODULE_CONF *MODULES::getconf (const char *name);
PUBLIC MODULE_ALIAS *MODULES::getalias (const char *name);
PUBLIC void MODULES::setalias (const char *alias, const char *module);
PUBLIC void MODULES::setoption (const char *module,
	 const char *option,
	 const char *value);
PUBLIC MODULE_VIRTDB::MODULE_VIRTDB (void);
PUBLIC int MODULE_VIRTDB::docmd (VIRTDB_CMD cmd,
	 int argc,
	 char *argv[]);
/* runlevels.cc 08/04/99 22.24.48 */
PRIVATE void RUNLEVELS::parse (const char *str, RUNLEVEL *ptrun);
PUBLIC RUNLEVELS::RUNLEVELS (int graphic_ok, int net_ok);
PUBLIC RUNLEVELS::~RUNLEVELS (void);
PUBLIC void RUNLEVELS::save (void);
PUBLIC int RUNLEVELS::find_initlevel (int initlevel);
PUBLIC int RUNLEVELS::setmenu (const char *menuopt[]);
PUBLIC RUNLEVEL *RUNLEVELS::getfromchoice (int choice);
PUBLIC void RUNLEVELS::setlevel (int choice);
PUBLIC void RUNLEVELS::config (void);
PUBLIC void RUNLEVELS::define (void);

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/askrunlevel/askrunlevel.pm <==
/* askrunlevel.cc 10/10/2000 14.02.44 */
/* boot.cc 28/10/2000 00.02.36 */
/* _dict.cc 14/08/1996 15.16.28 */
/* internal.cc 14/10/1995 01.33.40 */
/* linuxrc.cc 09/05/1997 23.34.38 */
/* modlist.cc 06/08/2000 23.47.20 */
/* modules.cc 24/11/2000 00.01.46 */
PUBLIC PARMVAL::PARMVAL (const char *_parm, const char *_line);
PUBLIC PARMVAL::PARMVAL (const char *_parm);
PUBLIC PARMVAL *PARMVALS::getitem (int no)const;
PUBLIC void PARMVALS::setoption (const char *optname, const char *val);
PUBLIC MODULE_LINE::MODULE_LINE (const SSTRING&pre_com,
	 const char *end_com);
PUBLIC MODULE_LINE::MODULE_LINE (void);
PUBLIC void MODULE_LINE::write (FILE_CFG *fout);
PUBLIC MODULE_LINE_IGNORE::MODULE_LINE_IGNORE (const char *_begin,
	 const SSTRING&pre_com,
	 const char *end_com);
PUBLIC void MODULE_LINE_IGNORE::write_begin (FILE_CFG *fout);
PUBLIC MODULE_LINE *MODULE_LINES::getitem (int no)const;
PUBLIC MODULE_CONF::MODULE_CONF (char *line,
	 const SSTRING&pre_com,
	 const char *end_com);
PUBLIC MODULE_CONF::MODULE_CONF (const char *_name);
PUBLIC void MODULE_CONF::write_begin (FILE_CFG *fout);
PUBLIC MODULE_CONF *MODULE_CONFS::getitem (int no)const;
PUBLIC MODULE_ALIAS::MODULE_ALIAS (const char *line,
	 const SSTRING&pre_com,
	 const char *end_com);
PUBLIC MODULE_ALIAS::MODULE_ALIAS (const char *_alias,
	 const char *_module);
PUBLIC void MODULE_ALIAS::write_begin (FILE_CFG *fout);
PUBLIC MODULE_ALIAS *MODULE_ALIASES::getitem (int no)const;
PUBLIC MODULES::MODULES (void);
PUBLIC int MODULES::write (void);
PUBLIC MODULE_CONF *MODULES::getconf (const char *name);
PUBLIC MODULE_ALIAS *MODULES::getalias (const char *name);
PUBLIC void MODULES::setalias (const char *alias, const char *module);
PUBLIC void MODULES::setoption (const char *module,
	 const char *option,
	 const char *value);
PUBLIC MODULE_VIRTDB::MODULE_VIRTDB (void);
PUBLIC int MODULE_VIRTDB::docmd (VIRTDB_CMD cmd,
	 int argc,
	 char *argv[]);
/* runlevels.cc 08/04/1999 23.27.14 */
PRIVATE void RUNLEVELS::parse (const char *str, RUNLEVEL *ptrun);
PUBLIC RUNLEVELS::RUNLEVELS (int graphic_ok, int net_ok);
PUBLIC RUNLEVELS::~RUNLEVELS (void);
PUBLIC void RUNLEVELS::save (void);
PUBLIC int RUNLEVELS::find_initlevel (int initlevel);
PUBLIC int RUNLEVELS::setmenu (const char *menuopt[]);
PUBLIC RUNLEVEL *RUNLEVELS::getfromchoice (int choice);
PUBLIC void RUNLEVELS::setlevel (int choice);
PUBLIC void RUNLEVELS::config (void);
PUBLIC void RUNLEVELS::define (void);
